@@ -25,28 +25,6 @@ class FlakyPlugin(Plugin):
         self._stream = StringIO()
         self._flaky_result = TextTestResult(self._stream, [], 0)
 
-    def options(self, parser, env):
-        """
-        Baseclass override. Sets up the plugin options that can be parsed.
-        :param parser:
-            The command line argument parser
-        :type parser:
-            :class:`OptionContainer`
-        :param env:
-            Environment variables
-        :type env:
-            `dict`
-        """
-        super(FlakyPlugin, self).options(parser, env=env)
-
-    def configure(self, options, conf):
-        """
-        Baseclass override. Configures the plugin based on parsed options.
-        """
-        super(FlakyPlugin, self).configure(options, conf)
-        if not self.enabled:
-            return
-
     def handleError(self, test, err):
         """
         Baseclass override. Called when a test raises an exception.
@@ -58,6 +36,10 @@ class FlakyPlugin(Plugin):
             Information about the test failure (from sys.exc_info())
         :type err:
             `tuple` of `class`, :class:`Exception`, `traceback`
+        :return:
+            True, if the test will be rerun; False, if nose should handle it.
+        :rtype:
+            `bool`
         """
         # pylint:disable=invalid-name
         return self._handle_test_error_or_failure(test, err)
@@ -73,6 +55,10 @@ class FlakyPlugin(Plugin):
             Information about the test failure (from sys.exc_info())
         :type err:
             `tuple` of `class`, :class:`Exception`, `traceback`
+        :return:
+            True, if the test will be rerun; False, if nose should handle it.
+        :rtype:
+            `bool`
         """
         # pylint:disable=invalid-name
         return self._handle_test_error_or_failure(test, err)
@@ -91,6 +77,10 @@ class FlakyPlugin(Plugin):
             The test that has succeeded
         :type test:
             :class:`nose.case.Test`
+        :return:
+            True, if the test will be rerun; False, if nose should handle it.
+        :rtype:
+            `bool`
         """
         # pylint:disable=invalid-name
         test_method, test_method_name = self._get_test_method_and_name(test)
@@ -122,13 +112,13 @@ class FlakyPlugin(Plugin):
             unicode(test_method_name),
             ' passed {} out of the required {} times. '.format(
                 current_passes,
-                min_passes
+                min_passes,
             ),
         ])
         if not self._has_flaky_test_succeeded(flaky):
             self._stream.write(
                 'Running test again until it passes {} times.\n'.format(
-                    min_passes
+                    min_passes,
                 )
             )
             test.run(self._flaky_result)
@@ -166,10 +156,10 @@ class FlakyPlugin(Plugin):
             if value is not None:
                 if not hasattr(
                         test_method,
-                        attr
+                        attr,
                 ) or getattr(
                         test_method,
-                        attr
+                        attr,
                 ) is None:
                     self._set_flaky_attribute(test_method, attr, value)
 
@@ -187,7 +177,7 @@ class FlakyPlugin(Plugin):
             unicode(err[1].message),
             '\n\t',
             unicode(err[2]),
-            '\n'
+            '\n',
         ])
 
     def _handle_test_error_or_failure(self, test, err):
@@ -199,11 +189,23 @@ class FlakyPlugin(Plugin):
         Returning True from this method keeps the test runner from reporting
         the test as a failure; this way we can retry and only report as a
         failure if we are out of retries.
+        :param test:
+            The test that has raised an error
+        :type test:
+            :class:`nose.case.Test`
+        :param err:
+            Information about the test failure (from sys.exc_info())
+        :type err:
+            `tuple` of `class`, :class:`Exception`, `traceback`
+        :return:
+            True, if the test will be rerun; False, if nose should handle it.
+        :rtype:
+            `bool`
         """
         test_method, test_method_name = self._get_test_method_and_name(test)
         current_runs = self._get_flaky_attribute(
             test_method,
-            FlakyNames.CURRENT_RUNS
+            FlakyNames.CURRENT_RUNS,
         )
         if current_runs is None:
             return False
@@ -211,7 +213,7 @@ class FlakyPlugin(Plugin):
         self._set_flaky_attribute(
             test_method,
             FlakyNames.CURRENT_RUNS,
-            current_runs
+            current_runs,
         )
         self._add_flaky_test_failure(test_method, err)
         flaky = self._get_flaky_attributes(test_method)
@@ -221,7 +223,7 @@ class FlakyPlugin(Plugin):
             runs_left = max_runs - flaky[FlakyNames.CURRENT_RUNS]
             message = self._retry_failure_message.format(
                 runs_left,
-                max_runs
+                max_runs,
             )
             self._log_test_failure(test_method_name, err, message)
             test.run(self._flaky_result)
@@ -231,13 +233,29 @@ class FlakyPlugin(Plugin):
             current_passes = flaky[FlakyNames.CURRENT_PASSES]
             message = self._failure_message.format(
                 current_passes,
-                min_passes
+                min_passes,
             )
             self._log_test_failure(test_method_name, err, message)
             return False
 
     @staticmethod
     def _get_flaky_attribute(test_method, flaky_attribute):
+        """
+        Gets an attribute describing the flaky test.
+        :param test_method:
+            The test method from which to get the attribute
+        :type test_method:
+            `callable`
+        :param flaky_attribute:
+            The name of the attribute to get
+        :type flaky_attribute:
+            `unicode`
+        :return:
+            The test method's attribute, or None if the test method doesn't
+            have that attribute.
+        :rtype:
+            varies
+        """
         return getattr(
             test_method,
             flaky_attribute,
@@ -246,25 +264,62 @@ class FlakyPlugin(Plugin):
 
     @staticmethod
     def _set_flaky_attribute(test_method, flaky_attribute, value):
+        """
+        Sets an attribute on a flaky test. Uses magic __dict__ since setattr
+        doesn't work for bound methods.
+        :param test_method:
+            The test method on which to set the attribute
+        :type test_method:
+            `callable`
+        :param flaky_attribute:
+            The name of the attribute to set
+        :type flaky_attribute:
+            `unicode`
+        :param value:
+            The value to set the test method's attribute to.
+        :type value:
+            varies
+        """
         test_method.__dict__[flaky_attribute] = value
 
     @classmethod
     def _get_flaky_attributes(cls, test_method):
+        """
+        Get all the flaky related attributes from the test method.
+        :param test_method:
+            The test method from which to get the flaky related attributes.
+        :type test_method:
+            `callable`
+        :return:
+        :rtype:
+            `dict` of `unicode` to varies
+        """
         return {
             attr: cls._get_flaky_attribute(
                 test_method,
-                attr
+                attr,
             ) for attr in FlakyNames()
         }
 
     @classmethod
     def _add_flaky_test_failure(cls, test_method, err):
+        """
+        Store test error information on the test method.
+        :param test_method:
+            The test method from which to get the flaky related attributes.
+        :type test_method:
+            `callable`
+        :param err:
+            Information about the test failure (from sys.exc_info())
+        :type err:
+            `tuple` of `class`, :class:`Exception`, `traceback`
+        """
         if not hasattr(test_method, FlakyNames.CURRENT_ERRORS):
             errs = []
             cls._set_flaky_attribute(
                 test_method,
                 FlakyNames.CURRENT_ERRORS,
-                errs
+                errs,
             )
         else:
             errs = getattr(test_method, FlakyNames.CURRENT_ERRORS)
@@ -272,6 +327,17 @@ class FlakyPlugin(Plugin):
 
     @staticmethod
     def _get_test_method_name(test):
+        """
+        Get the name of the test method from the test.
+        :param test:
+            The test that has raised an error or succeeded
+        :type test:
+            :class:`nose.case.Test`
+        :return:
+            The name of the test method that is being run by the test
+        :rtype:
+            `unicode`
+        """
         _, _, class_and_method_name = test.address()
         first_dot_index = class_and_method_name.index('.')
         test_method_name = class_and_method_name[first_dot_index + 1:]
@@ -279,14 +345,49 @@ class FlakyPlugin(Plugin):
 
     @classmethod
     def _get_test_method_and_name(cls, test):
+        """
+        Get the test method and test method name from the test.
+        :param test:
+            The test that has raised an error or succeeded
+        :type test:
+            :class:`nose.case.Test`
+        :return:
+            The test method (and its name) that is being run by the test
+        :rtype:
+            `tuple` of `callable`, `unicode`
+        """
         method_name = cls._get_test_method_name(test)
         return getattr(test.test, method_name), method_name
 
     @classmethod
     def _has_flaky_test_failed(cls, flaky):
+        """
+        Whether or not the flaky test has failed
+        :param flaky:
+            Dictionary of flaky attributes
+        :type flaky:
+            `dict` of `unicode` to varies
+        :return:
+            True if the flaky test should be marked as failure; False if
+            it should be rerun.
+        :rtype:
+            `bool`
+        """
         no_retry = flaky[FlakyNames.CURRENT_RUNS] >= flaky[FlakyNames.MAX_RUNS]
         return no_retry and not cls._has_flaky_test_succeeded(flaky)
 
     @staticmethod
     def _has_flaky_test_succeeded(flaky):
+        """
+        Whether or not the flaky test has succeeded
+        :param flaky:
+            Dictionary of flaky attributes
+        :type flaky:
+            `dict` of `unicode` to varies
+        :return:
+            True if the flaky test should be marked as success; False if
+            it should be rerun.
+        :rtype:
+            `bool`
+        """
         return flaky[FlakyNames.CURRENT_PASSES] >= flaky[FlakyNames.MIN_PASSES]
